==> haskell-monad-logger-0.3.42-105-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w
key:                  monad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  eb129978e3706ef3a21db66d38243b23
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-A8mPheDcfh1Ekf5r4bHp7w
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6 exceptions-0.10.7
    fast-logger-3.2.4-AXHM12y5MtZKIIwsnmTfyz
    lifted-base-0.2.3.12-Hi5wZUtfsE6DzwMEBNTci6
    monad-control-1.0.3.1-JNSSe1yK184K4km57LK5G2
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs stm-2.5.1.0
    stm-chans-3.0.0.9-FlU5K8NwXr3CuyuM0prvJs template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-IFFPlbMue7bJmNu16qahDQ
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.42-107-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-logger
version:              0.3.42
visibility:           public
id:                   monad-logger-0.3.42-JqeTk6zPcDZE7ttxNu3qt7
key:                  monad-logger-0.3.42-JqeTk6zPcDZE7ttxNu3qt7
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/monad-logger#readme
synopsis:             A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>

category:             System
abi:                  a9f75b8a936ab6eb0cfeb5b4e87254cc
exposed:              True
exposed-modules:      Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules:       Paths_monad_logger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-logger-0.3.42
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-logger
hs-libraries:         HSmonad-logger-0.3.42-JqeTk6zPcDZE7ttxNu3qt7
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G exceptions-0.10.7
    fast-logger-3.2.4-Jiy7JoGUrfbVNzVDnbkpD
    lifted-base-0.2.3.12-1HBO3Op8zVE5tiB5q2FpSk
    monad-control-1.0.3.1-AWs9fqYpVcWJcuZp9GC9fe
    monad-loops-0.4.3-LG7facWXNYz9W52syv7lz8 mtl-2.3.1
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77 stm-2.5.1.0
    stm-chans-3.0.0.9-FlU5K8NwXr3CuyuM0prvJs template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    transformers-base-0.4.6-7L9a8OndhmFGFbdTcYFq2b
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock

haddock-html:         /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
